module.exports={A:{A:{"1":"J D E F A UC","132":"B"},B:{"132":"C K L G M N O","260":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"1":"VC 8B I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB XC YC","516":"0 1 2 3 4 5 6 7 8 9 IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC"},D:{"1":"N O BB q r s t CB DB EB","2":"I AB J D E F A B C K L G M","132":"FB GB HB IB JB KB LB MB NB OB PB QB RB SB","260":"0 1 2 3 4 5 6 7 8 9 TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"1":"J aC bC","2":"I AB ZC EC","2052":"D E F A B C K L G cC dC FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC"},F:{"1":"F B C G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p jC kC lC mC 3B SC nC 4B"},G:{"2":"EC oC TC","1025":"E pC qC rC sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"1025":"AD"},I:{"1":"8B I H BD CD DD ED TC FD GD"},J:{"1":"D A"},K:{"1":"A B C u 3B SC 4B"},L:{"1":"H"},M:{"1":"2B"},N:{"2052":"A B"},O:{"1025":"5B"},P:{"1":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"260":"GC"},R:{"1":"TD"},S:{"516":"UD VD"}},B:1,C:"autocomplete attribute: on & off values",D:true};
