module.exports={A:{A:{"2":"J D E F A B UC"},B:{"2":"C K L G M N O","2052":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"2":"VC 8B I AB XC YC","1028":"0 1 2 3 4 5 6 7 8 9 OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","1060":"J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB"},D:{"2":"I AB J D E F A B C K L G M N O BB q r s t CB DB","226":"EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB","2052":"0 1 2 3 4 5 6 7 8 9 jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"2":"I AB J D ZC EC aC bC","772":"K L G 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","804":"E F A B C dC FC 3B","1316":"cC"},F:{"2":"F B C G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB jC kC lC mC 3B SC nC 4B","226":"NB OB PB QB RB SB TB UB VB","2052":"WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p"},G:{"2":"EC oC TC pC qC rC","292":"E sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"2":"AD"},I:{"1":"H","2":"8B I BD CD DD ED TC FD GD"},J:{"2":"D A"},K:{"2":"A B C 3B SC 4B","2052":"u"},L:{"2052":"H"},M:{"1028":"2B"},N:{"2":"A B"},O:{"2052":"5B"},P:{"2":"I HD ID","2052":"q r s t JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"2052":"GC"},R:{"2052":"TD"},S:{"1028":"UD VD"}},B:4,C:"text-decoration styling",D:true};
