module.exports={A:{A:{"2":"J D E F UC","129":"A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","129":"C K","1025":"L G M N O"},C:{"2":"VC 8B I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB XC YC","513":"0 1 2 3 4 5 6 7 8 9 HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","2":"I AB"},E:{"1":"AB J D E F A B C K L G aC bC cC dC FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","2":"I ZC EC"},F:{"1":"F B C G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p jC kC lC mC 3B SC nC 4B"},G:{"388":"E EC oC TC pC qC rC sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"2":"AD"},I:{"2":"8B BD CD DD","388":"I H ED TC FD GD"},J:{"2":"D","388":"A"},K:{"1":"A B C 3B SC 4B","388":"u"},L:{"388":"H"},M:{"641":"2B"},N:{"388":"A B"},O:{"388":"5B"},P:{"388":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"388":"GC"},R:{"388":"TD"},S:{"513":"UD VD"}},B:1,C:"Number input type",D:true};
