module.exports={A:{A:{"2":"F A B UC","8":"J D E"},B:{"2":"C K L G M N O","8":"P Q R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p v w","1025":"0 1 2 3 4 5 6 7 8 9 x y z H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","129":"VC 8B XC YC"},D:{"1":"CB","8":"I AB J D E F A B C K L G M N O BB q r s t DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p v w","1025":"0 1 2 3 4 5 6 7 8 9 x y z H 2B CC DC"},E:{"1":"A B C K L G FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","260":"I AB J D E F ZC EC aC bC cC dC"},F:{"2":"F","8":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC","584":"S T U V W X Y Z a b c d","1025":"e f g h i j k l m n o p","2052":"B C jC kC lC mC 3B SC nC 4B"},G:{"1":"E pC qC rC sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","8":"EC oC TC"},H:{"8":"AD"},I:{"8":"8B I BD CD DD ED TC FD GD","1025":"H"},J:{"1":"A","8":"D"},K:{"8":"A B C u 3B SC 4B"},L:{"1025":"H"},M:{"1":"2B"},N:{"2":"A B"},O:{"8":"5B"},P:{"1":"r s t","8":"I q HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"8":"GC"},R:{"8":"TD"},S:{"1":"UD VD"}},B:2,C:"MathML",D:true};
