module.exports={A:{A:{"2":"J D E UC","260":"F A B"},B:{"132":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","260":"C K L G M N O"},C:{"2":"VC 8B I AB XC YC","260":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC"},D:{"16":"I AB J D E F A B C K L","132":"0 1 2 3 4 5 6 7 8 9 G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"16":"ZC EC","132":"I AB J D E F A B C K L G aC bC cC dC FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC"},F:{"1":"C nC 4B","2":"F jC kC lC mC","16":"B 3B SC","132":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p"},G:{"16":"EC oC","132":"E TC pC qC rC sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"2":"AD"},I:{"16":"BD CD","132":"8B I H DD ED TC FD GD"},J:{"132":"D A"},K:{"1":"C 4B","2":"A","16":"B 3B SC","132":"u"},L:{"132":"H"},M:{"260":"2B"},N:{"260":"A B"},O:{"132":"5B"},P:{"132":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"132":"GC"},R:{"132":"TD"},S:{"260":"UD VD"}},B:5,C:"Mutation events",D:true};
