module.exports={A:{A:{"1":"B","2":"J D E F A UC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 L G M N O P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","129":"C K"},C:{"1":"0 1 2 3 4 5 6 7 8 9 cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","2":"VC 8B","260":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB","804":"I AB J D E F A B C K L XC YC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","260":"dB eB fB gB hB","388":"IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB","1412":"G M N O BB q r s t CB DB EB FB GB HB","1956":"I AB J D E F A B C K L"},E:{"1":"IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","129":"A B C K L G dC FC 3B 4B GC eC fC HC","1412":"J D E F bC cC","1956":"I AB ZC EC aC"},F:{"1":"VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p","2":"F jC kC","260":"QB RB SB TB UB","388":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB","1796":"lC mC","1828":"B C 3B SC nC 4B"},G:{"1":"IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","129":"uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC","1412":"E qC rC sC tC","1956":"EC oC TC pC"},H:{"1828":"AD"},I:{"1":"H","388":"FD GD","1956":"8B I BD CD DD ED TC"},J:{"1412":"A","1924":"D"},K:{"1":"u","2":"A","1828":"B C 3B SC 4B"},L:{"1":"H"},M:{"1":"2B"},N:{"1":"B","2":"A"},O:{"1":"5B"},P:{"1":"q r s t JD KD LD FC MD ND OD PD QD 6B 7B RD SD","260":"HD ID","388":"I"},Q:{"1":"GC"},R:{"1":"TD"},S:{"1":"VD","260":"UD"}},B:4,C:"CSS3 Border images",D:true};
