module.exports={A:{A:{"2436":"J D E F A B UC"},B:{"260":"N O","2436":"C K L G M","8196":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"2":"VC 8B I AB J D E F A B C K L G M N O BB q r XC YC","772":"s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB","4100":"0 1 2 3 4 5 6 7 8 9 TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC"},D:{"2":"I AB J D E F A B C","2564":"K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB","8196":"0 1 2 3 4 5 6 7 8 9 kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","10244":"VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB"},E:{"1":"C K L G 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","16":"ZC EC","2308":"A B FC 3B","2820":"I AB J D E F aC bC cC dC"},F:{"2":"F B jC kC lC mC 3B SC nC","16":"C","516":"4B","2564":"G M N O BB q r s t CB DB EB FB GB HB","8196":"XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p","10244":"IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB"},G:{"1":"zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","2":"EC oC TC","2820":"E pC qC rC sC tC uC vC wC xC yC"},H:{"2":"AD"},I:{"2":"8B I BD CD DD ED TC","260":"H","2308":"FD GD"},J:{"2":"D","2308":"A"},K:{"2":"A B C 3B SC","16":"4B","8196":"u"},L:{"8196":"H"},M:{"1028":"2B"},N:{"2":"A B"},O:{"8196":"5B"},P:{"2052":"HD ID","2308":"I","8196":"q r s t JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"8196":"GC"},R:{"8196":"TD"},S:{"4100":"UD VD"}},B:5,C:"Synchronous Clipboard API",D:true};
