module.exports={A:{A:{"2":"J UC","2340":"D E F A B"},B:{"2":"C K L G M N O","1025":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","2":"VC 8B XC","513":"pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b","545":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB YC"},D:{"2":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB","1025":"0 1 2 3 4 5 6 7 8 9 TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"1":"A B C K L G FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","2":"I AB ZC EC aC","164":"J","4644":"D E F bC cC dC"},F:{"2":"F B G M N O BB q r s t CB DB EB FB jC kC lC mC 3B SC","545":"C nC 4B","1025":"GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p"},G:{"1":"vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","2":"EC oC TC","4260":"pC qC","4644":"E rC sC tC uC"},H:{"2":"AD"},I:{"2":"8B I BD CD DD ED TC FD GD","1025":"H"},J:{"2":"D","4260":"A"},K:{"2":"A B 3B SC","545":"C 4B","1025":"u"},L:{"1025":"H"},M:{"1":"2B"},N:{"2340":"A B"},O:{"1025":"5B"},P:{"1025":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"1025":"GC"},R:{"1025":"TD"},S:{"1":"VD","4097":"UD"}},B:4,C:"Crisp edges/pixelated images",D:true};
