module.exports={A:{A:{"2":"F A B UC","8":"J D E"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","2":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","2":"VC","8":"8B I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB XC YC","194":"ZB aB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","8":"I AB J D E F A B","257":"BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB","769":"C K L G M N O"},E:{"1":"C K L G 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","8":"I AB ZC EC aC","257":"J D E F A bC cC dC","1025":"B FC 3B"},F:{"1":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p","2":"C 3B SC nC 4B","8":"F B jC kC lC mC"},G:{"1":"E qC rC sC tC uC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","8":"EC oC TC pC","1025":"vC wC xC"},H:{"8":"AD"},I:{"1":"I H ED TC FD GD","8":"8B BD CD DD"},J:{"1":"A","8":"D"},K:{"1":"u","8":"A B C 3B SC 4B"},L:{"1":"H"},M:{"1":"2B"},N:{"2":"A B"},O:{"1":"5B"},P:{"1":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"1":"GC"},R:{"1":"TD"},S:{"1":"UD VD"}},B:1,C:"Details & Summary elements",D:true};
