module.exports={A:{A:{"2":"J D E UC","132":"F A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","1028":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","2":"VC 8B","260":"I AB J D E F A B C K L G XC YC","1028":"M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","548":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB","1028":"HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB"},E:{"1":"6B JC KC LC MC NC hC 7B OC PC QC RC iC","2":"ZC EC","548":"I AB J D E F A B C K L G aC bC cC dC FC 3B 4B GC eC fC HC IC 5B gC"},F:{"1":"hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p 4B","2":"F","548":"B C jC kC lC mC 3B SC nC","1028":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB"},G:{"1":"6B JC KC LC MC NC 9C 7B OC PC QC RC","16":"EC","548":"E oC TC pC qC rC sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C"},H:{"132":"AD"},I:{"1":"H","16":"BD CD","548":"8B I DD ED TC","1028":"FD GD"},J:{"548":"D A"},K:{"1":"u 4B","548":"A B C 3B SC"},L:{"1":"H"},M:{"1":"2B"},N:{"132":"A B"},O:{"1":"5B"},P:{"1":"q r s t FC MD ND OD PD QD 6B 7B RD SD","1028":"I HD ID JD KD LD"},Q:{"1":"GC"},R:{"1":"TD"},S:{"1":"UD VD"}},B:4,C:"Media Queries: resolution feature",D:true};
