module.exports={A:{A:{"2":"J D E UC","2561":"A B","2692":"F"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","2561":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","16":"VC","1537":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB YC","1796":"8B XC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","16":"I AB J D E F A B C K L","1025":"NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB","1537":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB"},E:{"1":"L G GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","16":"I AB J ZC EC","1025":"D E F A B C bC cC dC FC 3B","1537":"aC","4097":"K 4B"},F:{"1":"eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p 4B","16":"F B C jC kC lC mC 3B SC","260":"nC","1025":"s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","1537":"G M N O BB q r"},G:{"1":"2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","16":"EC oC TC","1025":"E sC tC uC vC wC xC yC zC","1537":"pC qC rC","4097":"0C 1C"},H:{"2":"AD"},I:{"16":"BD CD","1025":"H GD","1537":"8B I DD ED TC FD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C u 3B SC 4B"},L:{"1":"H"},M:{"1":"2B"},N:{"2561":"A B"},O:{"1":"5B"},P:{"1025":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"1":"GC"},R:{"1":"TD"},S:{"1":"VD","1537":"UD"}},B:1,C:"input event",D:true};
