module.exports={A:{A:{"132":"J D E F A B UC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","132":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","33":"N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB","132":"VC 8B I AB J D E F XC YC","292":"A B C K L G M"},D:{"1":"0 1 2 3 4 5 6 7 8 9 aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","132":"I AB J D E F A B C K L G M","548":"N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB"},E:{"132":"I AB J D E ZC EC aC bC cC","548":"F A B C K L G dC FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC"},F:{"132":"F B C G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p jC kC lC mC 3B SC nC 4B"},G:{"132":"E EC oC TC pC qC rC sC","548":"tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"16":"AD"},I:{"1":"H","16":"8B I BD CD DD ED TC FD GD"},J:{"16":"D A"},K:{"1":"u","16":"A B C 3B SC 4B"},L:{"1":"H"},M:{"1":"2B"},N:{"132":"A B"},O:{"1":"5B"},P:{"1":"q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD","16":"I"},Q:{"1":"GC"},R:{"1":"TD"},S:{"1":"VD","33":"UD"}},B:4,C:"CSS unicode-bidi property",D:false};
