module.exports={A:{A:{"2":"J D E F A B UC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Y Z a b c d e f g h i j k l m n o p v w x y z H","2":"C K L G M N O","1028":"W X","1540":"P Q R S T U V"},C:{"1":"0 1 2 3 4 5 6 7 8 9 qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","2":"VC","164":"8B I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB XC YC","1540":"TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","292":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB","1028":"W X","1540":"tB uB vB wB u xB yB zB 0B 1B P Q R S T U V"},E:{"1":"G fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","292":"I AB J D E F A B C ZC EC aC bC cC dC FC 3B","1540":"K L 4B GC","3076":"eC"},F:{"1":"zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p","2":"F B C jC kC lC mC 3B SC nC 4B","292":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB","1028":"xB yB","1540":"iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u"},G:{"1":"7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","292":"E EC oC TC pC qC rC sC tC uC vC wC xC yC zC","1540":"0C 1C 2C 3C 4C 5C","3076":"6C"},H:{"2":"AD"},I:{"1":"H","292":"8B I BD CD DD ED TC FD GD"},J:{"292":"D A"},K:{"1":"u","2":"A B C 3B SC 4B"},L:{"1":"H"},M:{"1":"2B"},N:{"2":"A B"},O:{"1":"5B"},P:{"1":"q r s t QD 6B 7B RD SD","292":"I HD ID JD KD LD","1540":"FC MD ND OD PD"},Q:{"1540":"GC"},R:{"1":"TD"},S:{"1":"VD","1540":"UD"}},B:5,C:"CSS Logical Properties",D:true};
