module.exports={A:{A:{"1":"A B","2":"J D E F UC"},B:{"1":"C K L G M N O","516":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"132":"eB fB gB hB iB jB kB 9B lB AC mB nB oB","164":"VC 8B I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB XC YC","516":"pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a","1028":"0 1 2 3 4 5 6 7 8 9 b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC"},D:{"420":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB","516":"0 1 2 3 4 5 6 7 8 9 cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"1":"A B C K L G FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","132":"F dC","164":"D E cC","420":"I AB J ZC EC aC bC"},F:{"1":"C 3B SC nC 4B","2":"F B jC kC lC mC","420":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB","516":"PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p"},G:{"1":"vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","132":"tC uC","164":"E rC sC","420":"EC oC TC pC qC"},H:{"1":"AD"},I:{"420":"8B I BD CD DD ED TC FD GD","516":"H"},J:{"420":"D A"},K:{"1":"C 3B SC 4B","2":"A B","516":"u"},L:{"516":"H"},M:{"1028":"2B"},N:{"1":"A B"},O:{"516":"5B"},P:{"1":"q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD","420":"I"},Q:{"516":"GC"},R:{"516":"TD"},S:{"164":"UD VD"}},B:4,C:"CSS3 Multiple column layout",D:true};
