module.exports={A:{A:{"1":"B","2":"J D E F A UC"},B:{"2":"0 1 2 3 4 5 6 7 8 9 C K L G M N O P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"1":"K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB","2":"0 1 2 3 4 5 6 7 8 9 VC 8B I AB J D E F A B C dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC XC YC"},D:{"1":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB","2":"0 1 2 3 4 5 6 7 8 9 dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"1":"E F A B C dC FC 3B","2":"I AB J D ZC EC aC bC cC","129":"K L G 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC"},F:{"1":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB UB WB 4B","2":"F B C SB TB VB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p jC kC lC mC 3B SC nC"},G:{"1":"E sC tC uC vC wC xC yC zC","2":"EC oC TC pC qC rC","257":"0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"2":"AD"},I:{"1":"8B I ED TC FD GD","2":"H BD CD DD"},J:{"2":"D A"},K:{"1":"4B","2":"A B C u 3B SC"},L:{"2":"H"},M:{"2":"2B"},N:{"1":"B","2":"A"},O:{"2":"5B"},P:{"1":"I","2":"q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"2":"GC"},R:{"2":"TD"},S:{"1":"UD","2":"VD"}},B:7,C:"SPDY protocol",D:true};
