module.exports={A:{A:{"1":"B","4":"J D E F A UC"},B:{"1":"C K L G M","129":"0 1 2 3 4 5 6 7 8 9 N O P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"1":"J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB","4":"VC 8B I AB XC YC","129":"0 1 2 3 4 5 6 7 8 9 dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC"},D:{"1":"XB YB ZB aB bB cB dB eB fB gB","4":"I AB J","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"4":"I AB ZC EC","129":"J D E F A B C K L G aC bC cC dC FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC"},F:{"1":"C KB LB MB NB OB PB QB RB SB TB 3B SC nC 4B","4":"F B jC kC lC mC","129":"G M N O BB q r s t CB DB EB FB GB HB IB JB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p"},G:{"4":"EC oC TC","129":"E pC qC rC sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"4":"AD"},I:{"4":"BD CD DD","129":"8B I H ED TC FD GD"},J:{"129":"D A"},K:{"1":"C 3B SC 4B","4":"A B","129":"u"},L:{"129":"H"},M:{"129":"2B"},N:{"1":"B","4":"A"},O:{"129":"5B"},P:{"129":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"129":"GC"},R:{"129":"TD"},S:{"1":"UD","129":"VD"}},B:1,C:"dataset & data-* attributes",D:true};
