module.exports={A:{A:{"1":"B","2":"J D E F UC","164":"A"},B:{"1":"0 1 2 3 4 5 6 7 8 9 C K L G M N O P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","2":"VC 8B I AB XC YC","8":"J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB","328":"TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","2":"I AB J D E F A B C K L G M N O BB q r","8":"s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","584":"eB fB gB"},E:{"1":"K L G GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","2":"I AB J ZC EC aC","8":"D E F A B C bC cC dC FC 3B","1096":"4B"},F:{"1":"UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p","2":"F B C jC kC lC mC 3B SC nC 4B","8":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB","584":"RB SB TB"},G:{"1":"2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","8":"E EC oC TC pC qC rC sC tC uC vC wC xC yC zC 0C","6148":"1C"},H:{"2":"AD"},I:{"1":"H","8":"8B I BD CD DD ED TC FD GD"},J:{"8":"D A"},K:{"1":"u","2":"A","8":"B C 3B SC 4B"},L:{"1":"H"},M:{"1":"2B"},N:{"1":"B","36":"A"},O:{"1":"5B"},P:{"1":"q r s t ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD","2":"HD","8":"I"},Q:{"1":"GC"},R:{"1":"TD"},S:{"1":"VD","328":"UD"}},B:2,C:"Pointer events",D:true};
