module.exports={A:{A:{"2":"J D E F A B UC"},B:{"2":"C K L G M N O","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p v w x y z H","1537":"P Q R S T U V W X Y Z a b c"},C:{"2":"VC","932":"8B I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB XC YC","2308":"0 1 2 3 4 5 6 7 8 9 qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC"},D:{"2":"I AB J D E F A B C K L G M N O BB q r","545":"s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p v w x y z H 2B CC DC","1537":"YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c"},E:{"1":"6B JC KC LC MC NC hC 7B OC PC QC RC iC","2":"I AB J ZC EC aC","516":"B C K L G 3B 4B GC eC fC HC IC 5B gC","548":"F A dC FC","676":"D E bC cC"},F:{"2":"F B C jC kC lC mC 3B SC nC 4B","513":"MB","545":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB","1025":"e f g h i j k l m n o p","1537":"LB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d"},G:{"1":"6B JC KC LC MC NC 9C 7B OC PC QC RC","2":"EC oC TC pC qC","516":"5C 6C 7C HC IC 5B 8C","548":"tC uC vC wC xC yC zC 0C 1C 2C 3C 4C","676":"E rC sC"},H:{"2":"AD"},I:{"2":"8B I BD CD DD ED TC","545":"FD GD","1025":"H"},J:{"2":"D","545":"A"},K:{"2":"A B C 3B SC 4B","1025":"u"},L:{"1025":"H"},M:{"2308":"2B"},N:{"2":"A B"},O:{"1537":"5B"},P:{"545":"I","1025":"q r s t 7B RD SD","1537":"HD ID JD KD LD FC MD ND OD PD QD 6B"},Q:{"1537":"GC"},R:{"1537":"TD"},S:{"932":"UD","2308":"VD"}},B:5,C:"Intrinsic & Extrinsic Sizing",D:true};
