module.exports={A:{A:{"2":"J D E F A UC","132":"B"},B:{"1":"C K L G M N O","4":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H"},C:{"2":"VC 8B XC","4":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","8":"I AB YC"},D:{"2":"I AB J","4":"0 1 2 3 4 5 6 7 8 9 D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC"},E:{"2":"I AB J D E F A B C K L G ZC EC aC bC cC dC FC 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC"},F:{"2":"F B C jC kC lC mC 3B SC nC 4B","4":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p"},G:{"2":"EC oC","4":"E TC pC qC rC sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC"},H:{"2":"AD"},I:{"2":"BD CD DD","4":"8B I H ED TC FD GD"},J:{"2":"D","4":"A"},K:{"1":"C 4B","2":"A B 3B SC","4":"u"},L:{"4":"H"},M:{"4":"2B"},N:{"1":"B","2":"A"},O:{"4":"5B"},P:{"4":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"4":"GC"},R:{"4":"TD"},S:{"4":"UD VD"}},B:4,C:"DeviceOrientation & DeviceMotion events",D:true};
