module.exports={A:{A:{"1":"A B","2":"J D E F UC"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H","2":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC WC","2":"VC 8B XC YC","132":"I AB J D E F A B C K L G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB 9B lB AC mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p v w x y z H 2B CC DC","2":"I","16":"AB J D E r s t CB DB","132":"F A B C K L G M N O BB q"},E:{"1":"C K L G 3B 4B GC eC fC HC IC 5B gC 6B JC KC LC MC NC hC 7B OC PC QC RC iC","2":"I AB ZC EC aC","132":"J D E F A B bC cC dC FC"},F:{"1":"G M N O BB q r s t CB DB EB FB GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB u xB yB zB 0B 1B P Q R BC S T U V W X Y Z a b c d e f g h i j k l m n o p","2":"F B C jC kC lC mC 3B SC nC 4B"},G:{"2":"qC rC","132":"E sC tC uC vC wC xC yC zC 0C 1C 2C 3C 4C 5C 6C 7C HC IC 5B 8C 6B JC KC LC MC NC 9C 7B OC PC QC RC","514":"EC oC TC pC"},H:{"2":"AD"},I:{"2":"BD CD DD","260":"8B I ED TC","514":"H FD GD"},J:{"132":"A","260":"D"},K:{"2":"A B C 3B SC 4B","514":"u"},L:{"260":"H"},M:{"2":"2B"},N:{"514":"A","1028":"B"},O:{"2":"5B"},P:{"260":"I q r s t HD ID JD KD LD FC MD ND OD PD QD 6B 7B RD SD"},Q:{"260":"GC"},R:{"260":"TD"},S:{"1":"UD VD"}},B:1,C:"accept attribute for file input",D:true};
